@@ -32,7 +32,7 @@
 #include "seahorse-check-button-control.h"
 #include "seahorse-gconf.h"
 #include "seahorse-gtkstock.h"
-#include "seahorse-secure-entry.h"
+#include "seahorse-secure-buffer.h"
 #include "seahorse-widget.h"
 
 /* From seahorse-prefs-cache.c */
